stumpwm-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[STUMP] [PATCH] accept all character chars in dformat


From: Vitaly Mayatskikh
Subject: [STUMP] [PATCH] accept all character chars in dformat
Date: Wed, 18 Mar 2009 13:35:03 +0100
User-agent: Wanderlust/2.15.6 (Almost Unreal) Emacs/22.3 Mule/5.0 (SAKAKI)

dformat function strips non `base-char' characters now, and that
messes up non-ASCII window names in log.

diff --git a/primitives.lisp b/primitives.lisp
index d6107bb..27969aa 100644
--- a/primitives.lisp
+++ b/primitives.lisp
@@ -657,9 +657,9 @@ output directly to a file.")
   (when (>= *debug-level* level)
     (multiple-value-bind (sec m h) (decode-universal-time (get-universal-time))
       (format *debug-stream* "~2,'0d:~2,'0d:~2,'0d " h m sec))
     ;; strip out non base-char chars quick-n-dirty like
     (write-string (map 'string (lambda (ch)
-                                 (if (typep ch 'base-char)
+                                 (if (typep ch 'character)
                                      ch #\?))
                        (apply 'format nil fmt args))
                   *debug-stream*)))
@@ -657,9 +657,9 @@ output directly to a file.")
     (multiple-value-bind (sec m h) (decode-universal-time (get-universal-time))
       (format *debug-stream* "~2,'0d:~2,'0d:~2,'0d " h m sec))
-    ;; strip out non base-char chars quick-n-dirty like
+    ;; strip out non character chars quick-n-dirty like
     (write-string (map 'string (lambda (ch)

-- 
wbr, Vitaly




reply via email to

[Prev in Thread] Current Thread [Next in Thread]